@@ -8,7 +8,7 @@ use crate::rules::non_critical_lints::{
     no_console::NoConsoleConfig, no_empty_function::NoEmptyFunctionConfig,
     no_restricted_syntax::NoRestrictedSyntaxConfig, no_use_before_define::NoUseBeforeDefineConfig,
     prefer_regex_literals::PreferRegexLiteralsConfig, quotes::QuotesConfig, radix::RadixConfig,
-    yoda::YodaConfig,
+    valid_typeof::ValidTypeofConfig, yoda::YodaConfig,
 };
 
 #[derive(Debug, Clone, Copy, Serialize, Deserialize)]
@@ -142,4 +142,8 @@ pub struct LintConfig {
     #[cfg(feature = "non_critical_lints")]
     #[serde(default, alias = "noNewSymbol")]
     pub no_new_symbol: RuleConfig<()>,
+
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default, alias = "validTypeof")]
+    pub valid_typeof: RuleConfig<ValidTypeofConfig>,
 }
